@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2013
+* (C) Francesco Mondello 2009-2014
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 */
 
 #include <QColorDialog>
+#include <QTimer>
 #include <string>
 #include <iostream>
 #include "mainwindowimpl.h"
@@ -30,6 +31,9 @@
 #include "formats.h"
 #include "inisettings.h"
 #include "sizeutil.h"
+#include "updatechecker.h"
+#include "dialogmultipageeditor.h"
+#include "globals.h"
 
 using namespace Magick;
 using namespace std;
@@ -76,6 +80,8 @@ MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WFlags f)
 
     connect(labelPreview, SIGNAL(previewReady(int, int, double, double)), this, SLOT(showImageInformations(int, int, double, double)));
 
+    connect(checkRelative, SIGNAL(stateChanged(int)), this, SLOT(setRelativeSizeCheckboxes(int)));
+
     createActions();
     setupMenu();
     createContextMenu();
@@ -92,22 +98,15 @@ MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WFlags f)
     loadOptions();
 
     resetDisplays();
+
+    QTimer::singleShot(10000, this, SLOT(checkForUpdates()));
+
+    checkVersion();
 }
 
 MainWindowImpl::~MainWindowImpl()
 {
-    IniSettings::setWindowGeometry(saveGeometry());
-    IniSettings::setPreviewChecked(checkShowPreview->isChecked());
-    IniSettings::setScaleChecked(groupDimensions->isChecked());
-    IniSettings::setMeasure(comboResizeValues->currentIndex());
-    IniSettings::setAspectRatioChecked(checkRelative->isChecked());
-    IniSettings::setResolutionChecked(groupResolution->isChecked());
-    IniSettings::setImageDirChecked(checkSameDir->isChecked());
-    IniSettings::setRenameChecked(checkRename->isChecked());
-    IniSettings::setBgColorChecked(checkNoTransp->isChecked());
-    IniSettings::isOverWriteMode(checkOverwrite->isChecked());
-
-    IniSettings::settings->sync();
+    saveSettings();
 }
 
 void MainWindowImpl::importListFromArgv(QString fileName)
@@ -135,6 +134,8 @@ void MainWindowImpl::createActions()
     // "File" actions
     connect(actionOpenFiles, SIGNAL(triggered()), this, SLOT(openFiles()));
     connect(actionAddFiles, SIGNAL(triggered()), this, SLOT(addFiles()));
+    connect(actionImportWindowsIconIco, SIGNAL(triggered()), this, SLOT(importIcoFile()));
+    connect(actionImportPDFFile, SIGNAL(triggered()), this, SLOT(importPdfFile()));
 
     connect(actionShowOptions, SIGNAL(triggered()), this, SLOT(editSettings()));
     connect(actionClose, SIGNAL(triggered()), this, SLOT(close()));
@@ -153,7 +154,9 @@ void MainWindowImpl::createActions()
     connect(actionConvert, SIGNAL(triggered()), this, SLOT(elabora()));
 
     connect(actionInfo, SIGNAL(triggered()), this, SLOT(about()));
-    connect(actionDonate, SIGNAL(triggered()), this, SLOT(openPaypalLink()));
+    connect(actionDonatePaypal, SIGNAL(triggered()), this, SLOT(openPaypalLink()));
+    connect(actionDonateFlattr, SIGNAL(triggered()), this, SLOT(openFlattrLink()));
+    connect(actionReportBug, SIGNAL(triggered()), this, SLOT(bugReport()));
 }
 
 void MainWindowImpl::setupMenu()
@@ -161,6 +164,9 @@ void MainWindowImpl::setupMenu()
     menu_File->addAction(actionOpenFiles);
     menu_File->addAction(actionAddFiles);
     menu_File->addSeparator();
+    menu_File->addAction(actionImportWindowsIconIco);
+    menu_File->addAction(actionImportPDFFile);
+    menu_File->addSeparator();
     menu_File->addAction(actionShowOptions);
     menu_File->addSeparator();
     menu_File->addAction(actionClose);
@@ -213,6 +219,46 @@ void MainWindowImpl::addFiles()
         loadFiles(fileNames);
 }
 
+void MainWindowImpl::importIcoFile()
+{
+    QString path = IniSettings::latestOpenedDir();
+
+    QString fileName = QFileDialog::getOpenFileName(this,
+        tr("Open Icon file"), path, tr("Microsoft icon (*.ico *.icon)"));
+
+    if (!fileName.isEmpty())
+        openMultipageFile(fileName);
+}
+
+void MainWindowImpl::importPdfFile()
+{
+    QString path = IniSettings::latestOpenedDir();
+
+    QString fileName = QFileDialog::getOpenFileName(this,
+        tr("Open Pdf file"), path, tr("Portable Document Format (*.pdf)"));
+
+    if (!fileName.isEmpty())
+        openMultipageFile(fileName);
+}
+
+void MainWindowImpl::openMultipageFile(QString fileName)
+{
+    DialogMultipageEditor *dlg = new DialogMultipageEditor();
+
+    statusBar()->showMessage(tr("Analyzing the file. It may take a while, please wait..."));
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    dlg->readFile(fileName);
+    QApplication::restoreOverrideCursor();
+    statusBar()->clearMessage();
+
+    dlg->exec();
+
+    if (dlg->result() == 1) {
+        QStringList fileNames = dlg->fileNames();
+        loadFiles(fileNames);
+    }
+}
+
 void MainWindowImpl::loadFiles(QStringList fileNames)
 {
     treeWidget->clear();
@@ -532,7 +578,7 @@ void MainWindowImpl::loadOptions()
 
     lineDirectory->setText(QDir::toNativeSeparators(IniSettings::outputDir()));
     comboWFormats->setCurrentIndex(IniSettings::latestWrittenFormatIndex());
-    checkOverwrite->setChecked(IniSettings::isOverWriteMode());
+    checkOverwrite->setChecked(IniSettings::isOverwriteMode());
 
     loadQuality();
 
@@ -603,10 +649,12 @@ void MainWindowImpl::relativeSizeW()
 {
     double value = spin_geoWidth->value();
 
-    if (checkRelative->isChecked()) {
-        if (comboResizeValues->currentText() == "px") {
-            double relative_H = ( ((double)img_height * value) / (double)img_width);
-            spin_geoHeight->setValue((double)qRound(relative_H));
+    if (checkLinkAspect->isChecked()) {
+        if (checkRelative->isChecked()) {
+            if (comboResizeValues->currentText() == "px") {
+                double relative_H = ( ((double)img_height * value) / (double)img_width);
+                spin_geoHeight->setValue((double)qRound(relative_H));
+            }
         }
     }
 
@@ -622,12 +670,15 @@ void MainWindowImpl::relativeSizeH()
 {
     double value = spin_geoHeight->value();
 
-    if (checkRelative->isChecked()) {
-        if (comboResizeValues->currentText() == "px") {
-            double relative_V = ( ((double)img_width * value) / (double)img_height);
-            spin_geoWidth->setValue((double)qRound(relative_V));
+    if (checkLinkAspect->isChecked()) {
+        if (checkRelative->isChecked()) {
+            if (comboResizeValues->currentText() == "px") {
+                double relative_V = ( ((double)img_width * value) / (double)img_height);
+                spin_geoWidth->setValue((double)qRound(relative_V));
+            }
         }
     }
+
     if (comboResizeValues->currentText() == "%") {
         if (checkRelative->isChecked())
             spin_geoWidth->setValue(spin_geoHeight->value());
@@ -697,7 +748,10 @@ void MainWindowImpl::editSettings()
     DialogOptions dlg;
     dlg.exec();
 
-    loadOptions();
+    if (dlg.result() == 1) {
+        saveSettings();
+        loadOptions();
+    }
 }
 
 void MainWindowImpl::about()
@@ -769,6 +823,7 @@ void MainWindowImpl::selectGeometryUnit(QString unit)
     }
 }
 
+/* FIXME: Forse è meglio cambiare nome */
 void MainWindowImpl::showNewSizePreview()
 {
     if (comboResizeValues->currentText() == "%") {
@@ -832,6 +887,36 @@ void MainWindowImpl::resetDisplays()
     labelPixelGeometry->setText("");
 }
 
+void MainWindowImpl::checkVersion()
+{
+    int savedVersion = IniSettings::currentVersion();
+    int currentVersion = globals::CURRENT_INTERNAL_VERSION;
+
+    if (savedVersion < currentVersion) {
+		QString welcomePage = QString("http://fasterland.net/redirects/welcome.php?product=converseen&version=%1")
+			.arg(globals::VERSION);
+
+        QDesktopServices::openUrl(QUrl(welcomePage, QUrl::TolerantMode));
+        IniSettings::setCurrentVersion(currentVersion);
+    }
+}
+
+void MainWindowImpl::saveSettings()
+{
+    IniSettings::setWindowGeometry(saveGeometry());
+    IniSettings::setPreviewChecked(checkShowPreview->isChecked());
+    IniSettings::setScaleChecked(groupDimensions->isChecked());
+    IniSettings::setMeasure(comboResizeValues->currentIndex());
+    IniSettings::setAspectRatioChecked(checkRelative->isChecked());
+    IniSettings::setResolutionChecked(groupResolution->isChecked());
+    IniSettings::setImageDirChecked(checkSameDir->isChecked());
+    IniSettings::setRenameChecked(checkRename->isChecked());
+    IniSettings::setBgColorChecked(checkNoTransp->isChecked());
+    IniSettings::setOverwriteMode(checkOverwrite->isChecked());
+
+    IniSettings::settings->sync();
+}
+
 void MainWindowImpl::overwriteDialog(QString baseName)
 {
     /*
@@ -917,5 +1002,29 @@ QString MainWindowImpl::destinationPath()
 
 void MainWindowImpl::openPaypalLink()
 {
-    QDesktopServices::openUrl(QUrl("http://converseen.sourceforge.net/#donations", QUrl::TolerantMode));
+    QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=HQA6TBT5354FC", QUrl::TolerantMode));
+}
+
+void MainWindowImpl::openFlattrLink()
+{
+    QDesktopServices::openUrl(QUrl("http://converseen.fasterland.net/#donations", QUrl::TolerantMode));
+}
+
+void MainWindowImpl::checkForUpdates()
+{
+    UpdateChecker *up = new UpdateChecker();
+    up->checkForUpdates();
+}
+
+void MainWindowImpl::bugReport()
+{
+    QDesktopServices::openUrl(QUrl("https://github.com/Faster3ck/Converseen/issues", QUrl::TolerantMode));
+}
+
+void MainWindowImpl::setRelativeSizeCheckboxes(int state)
+{
+    if (state == 0)
+        checkLinkAspect->setEnabled(false);
+    else
+        checkLinkAspect->setEnabled(true);
 }
